% Dynamic Macroeconomics
% Problem Set 1 Question 1
% Written by Christian Rhl
% This version 29.10.2013
clc; clear all; close all;

% Open data set (Part a))
load('USMacrodata.mat');
TSize = length(USMacrodata.Quarter);

% Plot the time-series (Part b))
figure;
subplot(2,2,1);
plot(USMacrodata.Quarter, log(USMacrodata.GDPC1));
xlim([1947, 2014]);
title('Real GDP');
subplot(2,2,2);
plot(USMacrodata.Quarter, log(USMacrodata.GPDIC96));
xlim([1947, 2014]);
title('Real Gross Private Investment');
subplot(2,2,3);
plot(USMacrodata.Quarter, log(USMacrodata.PCECC96));
xlim([1947, 2014]);
title('Real Private Consumption');
subplot(2,2,4);
plot(USMacrodata.Quarter, log(USMacrodata.HOANBS));
xlim([1947, 2014]);
title('Hours worked');

% Compute the growth rates and plot them (Part c))

Dy = 4*100*(log(USMacrodata.GDPC1(2:end)) - log(USMacrodata.GDPC1(1:end-1)));
Dc = 4*100*(log(USMacrodata.PCECC96(2:end)) - log(USMacrodata.PCECC96(1:end-1)));
Di = 4*100*(log(USMacrodata.GPDIC96(2:end)) - log(USMacrodata.GPDIC96(1:end-1)));
Dh = 4*100*(log(USMacrodata.HOANBS(2:end)) - log(USMacrodata.HOANBS(1:end-1)));

figure;
subplot(2,2,1);
plot(USMacrodata.Quarter(2:end), Dy);
xlim([1947, 2014]);
title('Real GDP');
subplot(2,2,2);
plot(USMacrodata.Quarter(2:end),Di);
xlim([1947, 2014]);
title('Real Gross Private Investment');
subplot(2,2,3);
plot(USMacrodata.Quarter(2:end), Dc);
xlim([1947, 2014]);
title('Real Private Consumption');
subplot(2,2,4);
plot(USMacrodata.Quarter(2:end), Dh);
xlim([1947, 2014]);
title('Hours worked');

% Compute average growth rates and standard deviations (Part d))

mean_growth = [mean(Dy), mean(Dc), mean(Di), mean(Dh)];
std_growth  = [std(Dy), std(Dc), std(Di), std(Dh)];
relativestd_growth = [std(Dy)/std(Dy), std(Dc)/std(Dy), std(Di)/std(Dy), std(Dh)/std(Dy)];

disp('------------------------------------'),
disp('-----Facts about growth rates-------');
disp('     GDP   Consumption Investment  Hours');
disp([mean_growth; std_growth; relativestd_growth]);
disp('------------------------------------');


% Counterfactual time-path (Part e))

temp = datevec(USMacrodata.Datenumber);
IStart = find(temp(:,1) == 2003, 1, 'First');   % First quarter of 2003
IEnd = find(temp(:,1) == 2007, 1, 'First') + 3; % Fourth quarter of 2007

avg_growth = mean(Dy(IStart:IEnd))/(4*100);

temp2 = [1; Dy(IEnd + 1:end)/(4*100);];
T = length(temp2) - 1;

temp3 = [1; ones(T,1)*avg_growth];

figure;
hold on;
plot(USMacrodata.Quarter(IEnd +1:end),cumsum(temp2), '-r','LineWidth', 2.5);
plot(USMacrodata.Quarter(IEnd +1:end),cumsum(temp3), 'LineWidth', 2.5);
legend('Actual', 'Counterfactual');
title('US Economy: Counterfactual Time Path of Real GDP');
xlabel('Time');
ylabel('Real GDP (normalized to 1 in 2007q4)');
hold off;