% Simplified Version of Neoclassical Growth Model
% Written by Christian Rhl

clc; clear all; close all;

% Parameter values
beta =  0.97;               % Discount factor
rho = 1/beta - 1;           % Time preference rate
alpha = 0.33;               % Elasticity of out with respect to capital
A = 1;                      % Technology parameter
sigma = 1;                  % Intertemporal elasticity of subsitution 
delta = 1;                  % Depreciation rate
beta_new = 0.98;
rho_new = 1/beta_new - 1;

% Steady state values 
kbar = (alpha*A/(rho+delta))^(1/(1-alpha));
cbar = A*kbar^alpha - delta*kbar;
ybar = A*kbar^alpha;

% Question h: Initial capital stock ten percent below steady-state
T = 50;

k = zeros(T,1);
c = zeros(T,1);
y = zeros(T,1);

k(1,1) = 0.9*kbar;
c(1,1) = A*k(1,1)^alpha - delta*k(1,1);
y(1,1) = A*k(1,1)^alpha;

for t = 2:1:T
    
    k(t,1) = alpha*beta*y(t-1,1);
    c(t,1) = A*k(t,1)^alpha - delta*k(t,1);
    y(t,1) = A*k(t,1)^alpha;
        
end

figure(1);
subplot(3,1,1);
plot(k);
title('Capital');
subplot(3,1,2);
plot(y);
title('Output');
subplot(3,1,3);
plot(c);
title('Consumption');

% Question i: Increase in discount factor

% New steady state values 
kbar_new = (alpha*A/(rho_new+delta))^(1/(1-alpha));
cbar_new = A*kbar_new^alpha - delta*kbar_new;
ybar_new = A*kbar_new^alpha;

% Initial conditions
k(1:3,1) = kbar;
c(1:3,1) = A*kbar^alpha - delta*kbar;
y(1:3,1) = A*kbar^alpha;

for t = 4:1:T
    
    k(t,1) = alpha*beta_new*y(t-1,1);
    c(t,1) = A*k(t,1)^alpha - delta*k(t,1);
    y(t,1) = A*k(t,1)^alpha;
        
end

figure(2);
subplot(3,1,1);
plot(k);
title('Capital');
subplot(3,1,2);
plot(y);
title('Output');
subplot(3,1,3);
plot(c);
title('Consumption');

% Bonus: A first pass at RBC models
% Make the technology parameter stochastic

T = 50;

k = zeros(T,1);
c = zeros(T,1);
y = zeros(T,1);
i = zeros(T,1);
k(1,1) = 1*kbar;
c(1,1) = A*k(1,1)^alpha - delta*k(1,1);
y(1,1) = A*k(1,1)^alpha;
i(1,1) = y(1,1) - c(1,1);

for t = 2:1:T
    
    temp = 0.05 + (0.05--0.05)*rand;
    Atilde = A + temp;
    
    k(t,1) = alpha*beta*y(t-1,1);
    c(t,1) = Atilde*k(t,1)^alpha - delta*k(t,1);
    y(t,1) = Atilde*k(t,1)^alpha;
    i(t,1) = y(t,1) - c(t,1);    
end

figure(3);
subplot(4,1,1);
plot(k);
title('Capital');
subplot(4,1,2);
plot(y);
title('Output');
subplot(4,1,3);
plot(c);
title('Consumption');
subplot(4,1,4);
plot(i);
title('Investment');
